Crate near_contract_standards_sbt

Crate near_contract_standards_sbt 

Modules

fungible_token
Fungible tokens as described in by the spec.
non_fungible_token
Non-fungible tokens as described in by the spec.
storage_management
Storage management deals with handling state storage on NEAR. This follows the storage management standard.
upgradeDeprecated
This upgrade standard is a use case where a staging area exists for a WASM blob, allowing it to be stored for a period of time before deployed.

Macros

impl_fungible_token_core
The core methods for a basic fungible token. Extension standards may be added in addition to this macro.
impl_fungible_token_storage
Ensures that when fungible token storage grows by collections adding entries, the storage is be paid by the caller. This ensures that storage cannot grow to a point that the FT contract runs out of Ⓝ. Takes name of the Contract struct, the inner field for the token and optional method name to call when the account was closed.
impl_non_fungible_token_approval
Non-fungible token approval management allows for an escrow system where multiple approvals per token exist.
impl_non_fungible_token_core
The core methods for a basic non-fungible token. Extension standards may be added in addition to this macro.
impl_non_fungible_token_enumeration
Non-fungible enumeration adds the extension standard offering several view-only methods to get token supply, tokens per owner, etc.